Figures is a Django reusable app for `Open edX <https://open.edx.org/>`__ to provide site-wide and cross-course analytics to compliment Open edX's traditional course-centric analytics.

Please see the project `README <https://github.com/appsembler/figures/blob/master/README.rst>`__ on Github for more information.


## Requirements


### Figures 0.3.x


* Python (2.7)
* Django (1.11)
* Open edX Hawthorn

### Figures 0.2.x

* Python (2.7)
* Django (1.8)
* Open edX Ficus or Ginkgo
